
% WHAT IF...? OUTPUT LAYER

% FIG 5 panels A and B

% PANEL A

% THE PROBABILITY THAT THE NUMBER OF NUCLEAR CELLS ON THE x AXIS (IN THE
% RANGE 1 TO n) RECEIVES CONTACT FROM 1 OR MORE OR 2 OR MORE PURKINJE CELLS
% OUT OF A RANDOM SAMPLE OF m, WITH DIVERGENCE OF 1:z.

opengl software
figure;

% variables

m = 10; n = 50; x = [0:1:n]; z = 5;

% the probability a given nuclear cell (out of 50) receives contact from
% 0, 1, 2 or 3 out of m active PCs

Fx = factorial(n)./(factorial(x).*factorial(n-x));
Fm1 = factorial(m)./(factorial(1).*factorial(m-1));
Fm2 = factorial(m)./(factorial(2).*factorial(m-2));
Fm3 = factorial(m)./(factorial(3).*factorial(m-3));
p0 = (1-(z/n))^m;
p1 = (z/n)*((1-(z/n))^(m-1))*Fm1;
p2 = ((z/n)^2)*((1-(z/n))^(m-2))*Fm2;
p3 = ((z/n)^3)*((1-(z/n))^(m-3))*Fm3;

% the probability that x out of n nuclear cells receives contact from 
% 1, 2 or 3 out of m active PCs (not graphed)

P1 = (p1.^x).*((1-p1).^(n-x)).*Fx;
P2 = (p2.^x).*((1-p2).^(n-x)).*Fx;
P3 = (p3.^x).*((1-p3).^(n-x)).*Fx;

% the probability that x out of n nuclear cells receives contact from
% 1 or more, 2 or more, or 3 or more (out of m) active PCs

P1up = ((1-p0).^x).*(p0.^(n-x)).*Fx;
P2up = ((1-p0-p1).^x).*((p0+p1).^(n-x)).*Fx;
P3up = ((1-p0-p1-p2).^x).*((p0+p1+p2).^(n-x)).*Fx;

% Plot
subplot(2,2,1)
plot(x,P1up,'-o','MarkerSize',2.5,'color',[1 .75 .75],'MarkerFaceColor',[1 .75 .75])
xlabel('nuclear cells'); ylabel('p'); title('Monosynaptic divergence')
xlim([0 50]); ylim([0 0.35])
yticks([0 0.1 0.2 0.3])
set(gca,'FontSize',10)
hold on
plot(x,P2up,'-o','MarkerSize',2.5,'color',[.8 .45 .45],'MarkerFaceColor',[.7 .45 .45])
plot(x,P3up,'-o','MarkerSize',2.5,'color',[.5 .1 .1],'MarkerFaceColor',[.5 .1 .1])

% plot(x,P1up,'.','MarkerSize',2.2,'LineWidth',0.8)
% xlabel('nuclear cells');ylabel('prob');title('PC-DCN');xlim([0 50]);ylim([0 0.35]);
% hold on
% plot(x,P2up,'.','MarkerSize',2.2,'LineWidth',0.8)
% plot(x,P3up,'.','MarkerSize',2.2,'LineWidth',0.8)

% PANEL B

% THE SAME AS PANEL A BUT WITH HIGHER DIVERGENCE - 1:25, TO ILLUSTRATE 
% BISYNAPTIC DIVERGENCE, DERIVED FROM DIVERGENCE OF 1:5 AT EACH STEP 

% variables

m = 33; n = 50; x = [0:1:n]; z = 5;

% the probability a given nuclear cell (out of 50) receives contact from
% 0, 1, 2 or 3 out of m active PCs

Fx = factorial(n)./(factorial(x).*factorial(n-x));
Fm1 = factorial(m)./(factorial(1).*factorial(m-1));
Fm2 = factorial(m)./(factorial(2).*factorial(m-2));
Fm3 = factorial(m)./(factorial(3).*factorial(m-3));
p0 = (1-(z/n))^m;
p1 = (z/n)*((1-(z/n))^(m-1))*Fm1;
p2 = ((z/n)^2)*((1-(z/n))^(m-2))*Fm2;
p3 = ((z/n)^3)*((1-(z/n))^(m-3))*Fm3;

% the probability that x out of n nuclear cells receives contact from 
% 1, 2 or 3 out of m active PCs (not graphed)

P1 = (p1.^x).*((1-p1).^(n-x)).*Fx;
P2 = (p2.^x).*((1-p2).^(n-x)).*Fx;
P3 = (p3.^x).*((1-p3).^(n-x)).*Fx;

% the probability that x out of n nuclear cells receives contact from
% 1 or more, 2 or more, or 3 or more (out of m) active PCs

P1up = ((1-p0).^x).*(p0.^(n-x)).*Fx;
P2up = ((1-p0-p1).^x).*((p0+p1).^(n-x)).*Fx;
P3up = ((1-p0-p1-p2).^x).*((p0+p1+p2).^(n-x)).*Fx;

% Plot
subplot(2,2,2)
plot(x,P1up,'-o','MarkerSize',2.5,'color',[.9 .65 .65],'MarkerFaceColor',[.9 .65 .65])
xlabel('nuclear cells'); ylabel('P'); title('Disynaptic divergence')
xlim([0 50]); ylim([0 0.35])
yticks([0 0.1 0.2 0.3])
set(gca,'FontSize',10)
hold on
plot(x,P2up,'-o','MarkerSize',2.5,'color',[.7 .45 .45],'MarkerFaceColor',[.7 .45 .45])
plot(x,P3up,'-o','MarkerSize',2.5,'color',[.5 .25 .25],'MarkerFaceColor',[.5 .25 .25])

% stem(x,P1up,'o','filled','MarkerSize',2.2,'LineWidth',0.8)
% xlabel('nuclear cells');title('Nucleo-nuclear');xlim([0 50]);ylim([0 0.35])
% hold on
% stem(x,P2up,'o','filled','MarkerSize',2.2,'LineWidth',0.8)
% stem(x,P3up,'o','filled','MarkerSize',2.2,'LineWidth',0.8)
